.. _misdrijven:

misdrijven
##########

Titel XIX. Misdrijven tegen het leven gericht

  Artikel 287

   Hij die opzettelijk een ander van het leven berooft, wordt, als schuldig
   aan doodslag, gestraft met gevangenisstraf van ten hoogste vijftien jaren
   of geldboete van de vijfde categorie.

  Artikel 288

   Doodslag gevolgd, vergezeld of voorafgegaan van een strafbaar feit en
   gepleegd met het oogmerk om de uitvoering van dat feit voor te bereiden of
   gemakkelijk te maken, of om, bij betrapping op heter daad, aan zichzelf of
   andere deelnemers aan dat feit hetzij straffeloosheid hetzij het bezit van
   het wederrechtelijk verkregene te verzekeren, wordt gestraft met
   levenslange gevangenisstraf of tijdelijke van ten hoogste dertig jaren of
   geldboete van de vijfde categorie.

  Artikel 288a

   Doodslag, gepleegd met een terroristisch oogmerk, wordt gestraft met
   levenslange gevangenisstraf of tijdelijke van ten hoogste dertig jaren of
   geldboete van de vijfde categorie.

  Artikel 289

   Hij die opzettelijk en met voorbedachten rade een ander van het leven
   berooft, wordt, als schuldig aan moord, gestraft met levenslange
   gevangenisstraf of tijdelijke van ten hoogste dertig jaren of geldboete
   van de vijfde categorie.

  Artikel 289a

     1. De samenspanning tot het in artikel 289 omschreven misdrijf, te
        begaan met een terroristisch oogmerk, alsmede het in artikel 288a
        omschreven misdrijf, wordt gestraft met gevangenisstraf van ten
        hoogste tien jaren of geldboete van de vijfde categorie.

     2. Artikel 96, tweede lid, is van overeenkomstige toepassing.

  Artikel 290

   De moeder die, onder de werking van vrees voor de ontdekking van haar
   bevalling, haar kind bij of kort na de geboorte opzettelijk van het leven
   berooft, wordt, als schuldig aan kinderdoodslag, gestraft met
   gevangenisstraf van ten hoogste zes jaren of geldboete van de vierde
   categorie.

  Artikel 291

   De moeder die, ter uitvoering van een onder de werking van vrees voor de
   ontdekking van haar aanstaande bevalling genomen besluit, haar kind bij of
   kort na de geboorte opzettelijk van het leven berooft, wordt, als schuldig
   aan kindermoord, gestraft met gevangenisstraf van ten hoogste negen jaren
   of geldboete van de vijfde categorie.

  Artikel 292

   De in de artikelen 290 en 291 omschreven misdrijven worden ten aanzien van
   anderen die er aan deelnemen als doodslag of als moord aangemerkt.

  Artikel 293

     1. Hij die opzettelijk het leven van een ander op diens uitdrukkelijk
        en ernstig verlangen beëindigt, wordt gestraft met een gevangenisstraf
        van ten hoogste twaalf jaren of geldboete van de vijfde categorie.

     2. Het in het eerste lid bedoelde feit is niet strafbaar, indien het
        is begaan door een arts die daarbij voldoet aan de
        zorgvuldigheidseisen, bedoeld in artikel 2 van de Wet toetsing
        levensbeëindiging op verzoek en hulp bij zelfdoding en hiervan
        mededeling doet aan de gemeentelijke lijkschouwer overeenkomstig
        artikel 7, tweede lid, van de Wet op de lijkbezorging.

  Artikel 294

     1. Hij die opzettelijk een ander tot zelfdoding aanzet, wordt, indien
        de zelfdoding volgt, gestraft met een gevangenisstraf van ten hoogste
        drie jaren of geldboete van de vierde categorie.

     2. Hij die opzettelijk een ander bij zelfdoding behulpzaam is of hem
        de middelen daartoe verschaft, wordt, indien de zelfdoding volgt,
        gestraft met een gevangenisstraf van ten hoogste drie jaren of
        geldboete van de vierde categorie. Artikel 293, tweede lid, is van
        overeenkomstige toepassing.

  Artikel 295

     1. Bij veroordeling wegens doodslag, wegens moord of wegens een der in
        de artikelen 293, eerste lid, en 296 omschreven misdrijven, kan
        ontzetting van de in artikel 28, eerste lid, onder 1°, 2° en 4°,
        vermelde rechten worden uitgesproken.
 
     2. Indien de schuldige aan een der misdrijven in de artikelen 287 tot
        en met 289 omschreven, het misdrijf in zijn beroep begaat, kan hij van
        de uitoefening van dat beroep worden ontzet.
